/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.nginx.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.nginx.entity.NginxLog;
import com.yifu.cloud.plus.v1.nginx.service.NginxLogService;
import com.yifu.cloud.plus.v1.nginx.service.impl.NginxLogServiceImpl;
import com.yifu.cloud.plus.v1.nginx.vo.NginxLogSearchVo;
import com.yifu.cloud.plus.v1.yifu.common.core.util.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
 * 
 *
 * @author fxj
 * @date 2024-02-27 16:17:54
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/nginxlog" )
@Tag(name = "管理")
public class NginxLogController {

    private final NginxLogService nginxLogService;

    
    /**
     * 简单分页查询
     * @param page 分页对象
     * @param nginxLog 
     * @return
     */
    @Operation(description = "简单分页查询")
    @GetMapping("/page")
    public R<IPage<NginxLog>> getNginxLogPage(Page<NginxLog> page, NginxLogSearchVo nginxLog) {
        return  new R<>(nginxLogService.getNginxLogPage(page,nginxLog));
    }
    /**
     * 不分页查询
     * @param nginxLog 
     * @return
     */
    @Operation(summary = "不分页查询", description = "不分页查询")
    @PostMapping("/noPage" )
    //@PreAuthorize("@pms.hasPermission('demo_nginxlog_get')" )
    public R<List<NginxLog>> getNginxLogNoPage(@RequestBody NginxLogSearchVo nginxLog) {
        return R.ok(nginxLogService.noPageDiy(nginxLog));
    }

    /**
     * 通过id查询
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询：hasPermission('demo_nginxlog_get')")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('demo_nginxlog_get')" )
    public R<NginxLog> getById(@PathVariable("id" ) String id) {
        return R.ok(nginxLogService.getById(id));
    }

    /**
     * 新增
     * @param nginxLog 
     * @return R
     */
    @Operation(summary = "新增", description = "新增：hasPermission('demo_nginxlog_add')")
    @SysLog("新增" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('demo_nginxlog_add')" )
    public R<Boolean> save(@RequestBody NginxLog nginxLog) {
        return R.ok(nginxLogService.save(nginxLog));
    }

    /**
     * 修改
     * @param nginxLog 
     * @return R
     */
    @Operation(summary = "修改", description = "修改：hasPermission('demo_nginxlog_edit')")
    @SysLog("修改" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('demo_nginxlog_edit')" )
    public R<Boolean> updateById(@RequestBody NginxLog nginxLog) {
        return R.ok(nginxLogService.updateById(nginxLog));
    }

    /**
     * 通过id删除
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除", description = "通过id删除：hasPermission('demo_nginxlog_del')")
    @SysLog("通过id删除" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('demo_nginxlog_del')" )
    public R<Boolean> removeById(@PathVariable String id) {
        return R.ok(nginxLogService.removeById(id));
    }

    /**
	 *  批量导入
	 *
     * @author fxj
     * @date 2024-02-27 16:17:54
	 **/
    @SneakyThrows
    @Operation(description = "批量新增 hasPermission('demo_nginxlog-batch-import')")
    @SysLog("批量新增")
    @PostMapping("/importListAdd")
    @PreAuthorize("@pms.hasPermission('demo_nginxlog-batch-import')")
    public R<List<ErrorMessage>> importListAdd(@RequestBody MultipartFile file){
        return nginxLogService.importDiy(file.getInputStream());
    }

    /**
     *  批量导出
     * @author fxj
     * @date 2024-02-27 16:17:54
     **/
    @Operation(description = "导出 hasPermission('demo_nginxlog-export')")
    @PostMapping("/export")
    @PreAuthorize("@pms.hasPermission('demo_nginxlog-export')")
    public void export(HttpServletResponse response, @RequestBody NginxLogSearchVo searchVo) {
            nginxLogService.listExport(response,searchVo);
    }
}
